@@ -9,7 +9,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '4.007';
+$VERSION = '4.008';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -1071,7 +1071,12 @@ options to embedded server.
 
 Example:
 
+use DBI;
 $testdsn="DBI:mysqlEmb:database=test;mysql_embedded_options=--help,--verbose";
+$dbh = DBI->connect($testdsn,"a","b");
+
+This would cause the command line help to the embedded MySQL server library
+to be printed.
 
 
 =item mysql_embedded_groups
